#
# spec file for package python-sounddevice
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-sounddevice
Version:        0.4.7
Release:        1.1
Summary:        Module to play and record sound with Python
License:        MIT
URL:            https://python-sounddevice.readthedocs.io/
Source:         https://files.pythonhosted.org/packages/source/s/sounddevice/sounddevice-%{version}.tar.gz
BuildRequires:  %{python_module cffi >= 1.0}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  portaudio
BuildRequires:  python-rpm-macros
Requires:       portaudio
Requires:       python-cffi >= 1.0
Recommends:     python-numpy
BuildArch:      noarch
%python_subpackages

%description
This Python module provides bindings for the PortAudio library and a few
convenience functions to play and record NumPy arrays containing audio signals.

%prep
%setup -q -n sounddevice-%{version}

%build
chmod 644 examples/*
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %{python_files}
%doc NEWS.rst README.rst examples
%license LICENSE
%{python_sitelib}/{_sounddevice.py,sounddevice.py}
%pycache_only %{python_sitelib}/__pycache__/{sounddevice,_sounddevice}*

%{python_sitelib}/sounddevice-%{version}.dist-info

%check
# no upstream tests, examples needs devices

%changelog
* Mon Jun 10 2024 Dirk Müller <dmueller@suse.com>
- update to 0.4.7:
  * support paWinWasapiAutoConvert with auto_convert flag in
    WasapiSettings
  * Avoid exception in PortAudioError.__str__()
* Fri Dec 29 2023 Dirk Müller <dmueller@suse.com>
- update to 0.4.6:
  * Redirect stderr with os.dup2() instead of CFFI calls
* Fri Oct  7 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 0.4.5
  * Add index field to device dict
  * Require Python >= 3.7
  * Add PaWasapi_IsLoopback() to cdef (high-level interface not yet available)
* Mon Apr 19 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.4.1:
  * CallbackFlags attributes are now writable
- Don't build for Python 3.6, NumPy isn't available
* Wed Jul 29 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 0.4.0
  * Drop support for Python 2.x
  * Fix memory issues in `play()`, `rec()` and `playrec()`
  * Example application ``play_stream.py``
  * Remove ``print_devices()``, `query_devices()` can be used instead
* Thu Mar 26 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 0.3.15
  * This will be the last release supporting Python 2.x!
* Fri Mar 13 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix fdupes call
* Mon Dec  2 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.3.14
  * Examples play_sine.py and rec_gui.py
  * Redirect stderr only during initialization
* Sun Jun  2 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Tue May 21 2019 pgajdos@suse.com
- version update to 0.3.13
  * Examples asyncio_coroutines.py and asyncio_generators.py
- package examples
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Wed Oct 31 2018 Todd R <toddrme2178@gmail.com>
- Update to 0.3.12
  * Support for the dylib from Anaconda
* Tue May  8 2018 toddrme2178@gmail.com
- Update to 0.3.11 (2018-05-07):
  * Support for the DLL from ``conda-forge``
- Update to 0.3.10 (2017-12-22):
  * Change the way how the PortAudio library is located
- Update to 0.3.9 (2017-10-25):
  * Add `sounddevice.Stream.closed`
  * Switch CFFI usage to "out-of-line ABI" mode
* Tue Aug  8 2017 toddrme2178@gmail.com
- Initial version
